@@ -1,4 +1,5 @@
 # see: https://docs.python.org/3/library/socketserver.html
+import socket
 import socketserver
 import traceback
 from abc import abstractmethod, ABC
@@ -41,10 +42,13 @@ class PsqlHandler(ABC, socketserver.StreamRequestHandler, socketserver.Threading
     def init_ssl(self, context: Context):
         raise Exception("Not implemented")
 
+
     def handle(self):
 
         print(f"First Connect")
 
+        self.request.settimeout(5)
+
         input = ReadingIO(self.rfile)
         output = WritingIO(self.wfile)
 
@@ -71,7 +75,8 @@ class PsqlHandler(ABC, socketserver.StreamRequestHandler, socketserver.Threading
 
             context, state_name = run_states(context, state_name)
 
-
+        except socket.timeout as  e:
+            print("connection timed out")
         except Exception as e:
             print(e)
             try:
